raft_fleet v0.1.14 RaftFleet.Manager.State
Summary
Functions
Type-aware getter for activate_worker
Type-aware setter for activate_worker
Type-aware getter for adjust_timer
Type-aware setter for adjust_timer
Type-aware getter for adjust_worker
Type-aware setter for adjust_worker
Type-aware getter for being_added_consensus_groups
Type-aware setter for being_added_consensus_groups
Type-aware getter for deactivate_worker
Type-aware setter for deactivate_worker
Creates a new instance of Elixir.RaftFleet.Manager.State by using the given dict and the default value of each field.
Returns {:ok, valid_struct} or {:error, reason}.
The values in the dict are validated by each field’s validate/1 function
A variant of new/1 which returns t or raise if validation fails.
In other words, new/1 followed by Croma.Result.get!/1
Type-aware getter for purge_wait_timer
Type-aware setter for purge_wait_timer
Updates an existing instance of Elixir.RaftFleet.Manager.State with the given dict.
The values in the dict are validated by each field’s validate/1 function.
Returns {:ok, valid_struct} or {:error, reason}
A variant of update/2 which returns t or raise if validation fails.
In other words, update/2 followed by Croma.Result.get!/1
Checks that the given dict is valid or not by using each field’s validate/1 function.
Returns {:ok, valid_struct} or {:error, reason}
A variant of validate/1 which returns t or raise if validation fails.
In other words, validate/1 followed by Croma.Result.get!/1
Types
t() :: %RaftFleet.Manager.State{activate_worker: Croma.TypeGen.Nilable.Croma.Pid.t, adjust_timer: Croma.TypeGen.Nilable.Croma.Reference.t, adjust_worker: Croma.TypeGen.Nilable.Croma.Pid.t, being_added_consensus_groups: Croma.Map.t, deactivate_worker: Croma.TypeGen.Nilable.Croma.Pid.t, purge_wait_timer: Croma.TypeGen.Nilable.Croma.Reference.t}
Functions
Type-aware getter for activate_worker.
Type-aware setter for activate_worker.
Type-aware getter for adjust_timer.
Type-aware setter for adjust_timer.
Type-aware getter for adjust_worker.
Type-aware setter for adjust_worker.
Type-aware getter for being_added_consensus_groups.
Type-aware setter for being_added_consensus_groups.
Type-aware getter for deactivate_worker.
Type-aware setter for deactivate_worker.
Creates a new instance of Elixir.RaftFleet.Manager.State by using the given dict and the default value of each field.
Returns {:ok, valid_struct} or {:error, reason}.
The values in the dict are validated by each field’s validate/1 function.
A variant of new/1 which returns t or raise if validation fails.
In other words, new/1 followed by Croma.Result.get!/1.
Type-aware getter for purge_wait_timer.
Type-aware setter for purge_wait_timer.
Updates an existing instance of Elixir.RaftFleet.Manager.State with the given dict.
The values in the dict are validated by each field’s validate/1 function.
Returns {:ok, valid_struct} or {:error, reason}.
A variant of update/2 which returns t or raise if validation fails.
In other words, update/2 followed by Croma.Result.get!/1.
Checks that the given dict is valid or not by using each field’s validate/1 function.
Returns {:ok, valid_struct} or {:error, reason}.
A variant of validate/1 which returns t or raise if validation fails.
In other words, validate/1 followed by Croma.Result.get!/1.